aboutsummaryrefslogtreecommitdiff
path: root/lib/Target/X86/X86JITInfo.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/Target/X86/X86JITInfo.h')
-rw-r--r--lib/Target/X86/X86JITInfo.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/Target/X86/X86JITInfo.h b/lib/Target/X86/X86JITInfo.h
index 65a417dde8..dd26636433 100644
--- a/lib/Target/X86/X86JITInfo.h
+++ b/lib/Target/X86/X86JITInfo.h
@@ -37,11 +37,11 @@ namespace llvm {
///
virtual void replaceMachineCodeForFunction(void *Old, void *New);
- /// emitGlobalValueNonLazyPtr - Use the specified MachineCodeEmitter object
- /// to emit a Mac OS X non-lazy pointer which contains the address of the
- /// specified ptr.
- virtual void *emitGlobalValueNonLazyPtr(const GlobalValue* GV, void *ptr,
- MachineCodeEmitter &MCE);
+ /// emitGlobalValueIndirectSym - Use the specified MachineCodeEmitter object
+ /// to emit an indirect symbol which contains the address of the specified
+ /// ptr.
+ virtual void *emitGlobalValueIndirectSym(const GlobalValue* GV, void *ptr,
+ MachineCodeEmitter &MCE);
/// emitFunctionStub - Use the specified MachineCodeEmitter object to emit a
/// small native function that simply calls the function at the specified